module.exports = {
    PICS_FOLDER: 'Pictures/Pics.rs',
    SCREENSHOTS_FOLDER: 'Screenshots',
    CONFIGINI: 'config.ini',

    executeCommand: function( nw, command, callback ) {
        var child = nw.exec(command, function (error, stdout, stderr) {
            typeof callback === 'function' && callback();
        });
    },

    checkFoldersFiles: function(nw, callback) {
        var self = this,
            homedir = this.getHomeDir(),
            picsPath = homedir + '/' + this.PICS_FOLDER,
            configini = picsPath + '/' + this.CONFIGINI;

        nw.fs.exists( configini, function (exists) {
            console.log( "Check if config.ini exists", exists );
            if (!exists) {
                console.log('config.ini doesnt exist');
                self.createInitialFiles(nw);
            }
            callback();
        });
    },

    createInitialFiles: function(nw) {
        var homedir = this.getHomeDir(),
            picsPath = homedir + '/' + this.PICS_FOLDER,
            screenshotsPath = picsPath + '/' + this.SCREENSHOTS_FOLDER,
            configini = picsPath + '/' + this.CONFIGINI;

        try {
            nw.fs.mkdirSync(picsPath);
            nw.fs.mkdirSync(screenshotsPath);
            nw.fs.writeFileSync(configini, "");
            this.defaultIni();
        } catch(e) {
            console.log(e);
        }

    },

    defaultIni: function() {
        this.addConfigIni('token','notset','account');

        this.addConfigIni('screenshot_hotkey','S','keyboard');
        this.addConfigIni('screenshot_modifier','Ctrl+Alt','keyboard');

        this.addConfigIni('save_screenshots_in_folder','1','system');
        this.addConfigIni('check_for_updates_on_startup','1','system');

        this.addConfigIni('screenshot_capture_sound','shutter.aif','sound');
        this.addConfigIni('screenshot_upload_sound','keypress.mp3','sound');
        this.addConfigIni('retina_image_resize','auto','image');
    },

    getScreenshotsFolder: function() {
        var homedir = this.getHomeDir();
        return homedir + '/' + this.PICS_FOLDER + '/' + this.SCREENSHOTS_FOLDER;
    },

    parseConfigIni: function(callback) {
        var self = this,
            fs = require('fs'),
            ini = require('ini'),
            homedir = this.getHomeDir(),
            picsPath = homedir + '/' + this.PICS_FOLDER,
            configini = picsPath + '/' + this.CONFIGINI;

        try {
            var config = ini.parse(fs.readFileSync(configini, 'utf-8'))
        } catch(e) {
            nw.fs.writeFileSync(configini, "");
            this.defaultIni();
        }

        console.log("config.ini succesfully parsed", config);
        window.config = config;
        callback(config);
    },

    addConfigIni: function(field, val, section) {
        var fs = require('fs'),
            ini = require('ini'),
            homedir = this.getHomeDir(),
            picsPath = homedir + '/' + this.PICS_FOLDER,
            configini = picsPath + '/' + this.CONFIGINI;

        var config = ini.parse(fs.readFileSync(configini, 'utf-8'))

        if (!config[section]) {
            config[section] = {};
        }
        config[section][field] = val;

        window.config = config;
        fs.writeFileSync(configini, ini.stringify(config))
    },

    getAllSounds: function() {
        var fs = require('fs'),
            files = fs.readdirSync('./sounds');

        // files.unshift('None');
        return files;
    },

    getHomeDir: function() {
        return process.env['HOME'];
    }
}